# tinyscibio

[![PyPI version](https://img.shields.io/pypi/v/tinyscibio)](https://pypi.org/project/tinyscibio/)
![Python versions](https://img.shields.io/pypi/pyversions/tinyscibio)
[![PyPI Downloads](https://img.shields.io/pypi/dm/tinyscibio)](https://pypistats.org/packages/tinyscibio)
![License](https://img.shields.io/pypi/l/tinyscibio)

tinyscibio provides convenient shortcut functions to boost daily bioinformatics
work.

## Installation

You can install tinyscibio from PyPI.

```bash
pip install tinyscibio
```

## Getting started

Please refer to [documentation](https://svm-zhang.github.io/tinyscibio) for more details.
